@@ -19,7 +19,7 @@ class UserApi(BaseUserApi):
     extension = True
 
     @async_action
-    async def api_sign_in_by_password(self, view, **kwargs):
+    async def public_api_sign_in_by_password(self, view, **kwargs):
         action = kwargs['_action']
         try:
             login = view.data['login']
@@ -43,7 +43,7 @@ class UserApi(BaseUserApi):
         return action
 
     @async_action
-    async def api_sign_up_by_password(self, view, **kwargs):
+    async def public_api_sign_up_by_password(self, view, **kwargs):
         action = kwargs['_action']
         try:
             login = view.data['login']
@@ -70,7 +70,7 @@ class UserApi(BaseUserApi):
         return salt + hashlib.pbkdf2_hmac('sha256', password.encode('utf-8'), salt, 100000)
 
     @async_action
-    async def api_read_session_info(self, view, **kwargs):
+    async def public_api_read_session_info(self, view, **kwargs):
         action = kwargs['_action']
         try:
             user_link = view.session.get('user')
@@ -78,7 +78,7 @@ class UserApi(BaseUserApi):
                 return web.json_response({"session": view.session.identity})
             # user = action.add_stat(self.handler.init_by_ref(user_link, lang=view.lang, form='CurrentUser'))
             user = User(view.storage, lang=view.lang, form='CurrentUser')
-            action.add_stat(await user.find_by_link(user_link))
+            action.add_stat(await user.find_by_id(user_link['_id'], _form=None))
             result = {
                 "session": view.session.identity,
                 "user": view.session.get('user'),
